# wig2bed

**DOI:** [10.5281/zenodo.18895804](https://doi.org/10.5281/zenodo.18895804)

## Available Versions
- **Version 2.4.41**
  - [Download](https://zenodo.org/record/18895805/files/wig2bed_2.4.41.img)
  - **MD5:** `21d847b53e68b0957fcaf6236548c657`
  - **DOI:** [10.5281/zenodo.18895805](https://doi.org/10.5281/zenodo.18895805)
  - **Size:** 56.76 MB
  - **Binaries:** 0 available

## Binaries (35 total)

```bedmap bedops closest-features sort-bed starch starchcat unstarch wig2bed wig2bed_bin wig2starch wig2starch_bin bam2bed bam2bed_bin bam2starch bam2starch_bin vcf2bed vcf2bed_bin vcf2starch vcf2starch_bin gff2bed gff2bed_bin gff2starch gff2starch_bin gtf2bed gtf2bed_bin gtf2starch gtf2starch_bin psl2bed psl2bed_bin psl2starch psl2starch_bin rmsk2bed rmsk2bed_bin rmsk2starch rmsk2starch_bin```
